@@ -16,6 +16,10 @@ import os
 import sys
 
 import paramiko
+import pkg_resources
+
+
+__version__ = pkg_resources.require('next-review')[0].version
 
 
 DEFAULT_GERRIT_HOST = 'review.openstack.org'
@@ -30,14 +34,14 @@ def ssh_client(host, port, user=None, key=None):
     return client
 
 
-def get_watched_reviews(client, projects):
+def get_reviews(client, projects):
     reviews = []
 
     while True:
         project_query = '(' + ' OR '.join(projects) + ')'
         query = [
-            'gerrit', 'query', project_query, 'is:open', 'limit:100',
-            '--current-patch-set', '--comments', '--format=JSON']
+            'gerrit', 'query', project_query, 'is:open', '(-Verified-1)',
+            'limit:100', '--current-patch-set', '--comments', '--format=JSON']
         if reviews:
             query.append('resume_sortkey:%s' % reviews[-2]['sortKey'])
         stdin, stdout, stderr = client.exec_command(' '.join(query))
@@ -88,6 +92,16 @@ def require_jenkins_upvote(reviews):
     return filtered_reviews
 
 
+def ignore_all_downvotes(reviews):
+    filtered_reviews = []
+    for review in reviews:
+        votes = votes_by_name(review)
+        values = set(votes.itervalues())
+        if not set((-1, -2)) & values:
+            filtered_reviews.append(review)
+    return filtered_reviews
+
+
 def ignore_smokestack_downvotes(reviews):
     """Smokestack doesn't verify all reviews, so we can't require upvotes."""
     filtered_reviews = []
@@ -147,13 +161,15 @@ def main(args):
     client = ssh_client(
         host=args.host, port=args.port, user=args.username, key=args.key)
 
-    reviews = get_watched_reviews(client, args.projects)
+    reviews = get_reviews(client, args.projects)
 
     # filter out reviews that are not prime review targets
     reviews = ignore_wip(reviews)
     reviews = ignore_blocked_reviews(reviews)
     reviews = require_jenkins_upvote(reviews)
     reviews = ignore_smokestack_downvotes(reviews)
+    if args.nodownvotes:
+        reviews = ignore_all_downvotes(reviews)
     reviews = ignore_my_reviews(
         reviews, username=args.username, email=args.email)
     reviews = ignore_previously_reviewed(
@@ -182,27 +198,38 @@ def cli():
         prog='next-review',
         description='Start your next gerrit code review without any hassle.')
     parser.add_argument(
-        '--host', default=DEFAULT_GERRIT_HOST,
+        '--version', action='store_true',
+        help='Show version number and exit')
+    parser.add_argument(
+        '-H', '--host', default=DEFAULT_GERRIT_HOST,
         help='SSH hostname for gerrit')
     parser.add_argument(
-        '--port', type=int, default=DEFAULT_GERRIT_PORT,
+        '-p', '--port', type=int, default=DEFAULT_GERRIT_PORT,
         help='SSH port for gerrit')
     parser.add_argument(
         '-u', '--username', default=os.getlogin(),
         help='Your SSH username for gerrit')
     parser.add_argument(
-        '--email', default=None,
+        '-e', '--email', default=None,
         help='Your email address for gerrit')
     parser.add_argument(
-        '--key', default=None,
+        '-k', '--key', default=None,
         help='Path to your SSH public key for gerrit')
     parser.add_argument(
-        '--list', action='store_true',
+        '-l', '--list', action='store_true',
         help='List recommended code reviews in order of descending priority.')
+    parser.add_argument(
+        '-n', '--nodownvotes', action='store_true',
+        help='Ignore reviews that have a downvote from anyone.')
     parser.add_argument(
         'projects', metavar='project', nargs='*', default=['is:watched'],
         help='Projects to include when checking reviews.')
     args = parser.parse_args()
+
+    if args.version:
+        print pkg_resources.require('next-review')[0]
+        sys.exit()
+
     main(args)
 
 
